@@ -32,12 +32,12 @@
     if(sw["psi.sw"]) {
       psi.store  <- matrix(0L, nrow=P, ncol=n.store)
     }
-    post.mu      <- vector("integer", P)
+    post.mu      <- integer(P)
     post.psi     <- post.mu
-    ll.store     <- vector("integer", n.store)
+    ll.store     <-
+    Q.store      <- integer(n.store)
     Q.star       <- Q
     Q0           <- Q   > 0
-    Q.store      <- vector("integer", n.store)
     Q.large      <- Q.big  <- FALSE
     nu1.5        <- nu1 + 0.5
     P.5          <- P/2
@@ -82,7 +82,7 @@
     # Adaptation
       if(adapt   && all(iter >= start.AGS, iter < stop.AGS))      {
         if(stats::runif(1) < ifelse(iter < AGS.burn, 0.5, exp(-b0 - b1 * (iter - start.AGS)))) {
-          colvec <- (if(Q0)  colSums(abs(lmat)  < epsilon) / P   else stats::runif(1)) >= prop
+          colvec <- if(Q0)  (colSums2(abs(lmat) < epsilon) / P)  >= prop else stats::runif(1) <= prop
           numred <- sum(colvec)
           if(numred == 0)  {
             Q    <- Q + 1L
@@ -95,7 +95,7 @@
               tau   <- cumprod(delta)
               lmat  <- cbind(lmat, stats::rnorm(n=P, mean=0, sd=1/sqrt(phi[,Q] * tau[Q])))
             }
-          } else if(Q > 0)      {
+          } else if(Q0)         {
             nonred  <- colvec  == 0
             Q       <- max(0L, Q - numred)
             phi     <- phi[,nonred, drop=FALSE]
